OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Добавено към любимите",
    "Removed from favorites" : "Премахни от любимите",
    "You added {file} to your favorites" : "Добавихте {file} към любимите",
    "You removed {file} from your favorites" : "Премахнахте {file} от любимите",
    "Favorites" : "Любими",
    "File changes" : "Файлови промени",
    "Created by {user}" : "Създаден от {user}",
    "Changed by {user}" : "Променен от {user}",
    "Deleted by {user}" : "Изтрит от {user}",
    "Restored by {user}" : "Възстановен от {user}",
    "Renamed by {user}" : "Преименуван от {user}",
    "Moved by {user}" : "Преместен от {user}",
    "You created {file}" : "Създадохте {file}",
    "You created an encrypted file in {file}" : "Създадохте криптиран файл в {file}",
    "{user} created {file}" : "{user} създаде {file}",
    "{user} created an encrypted file in {file}" : "{user} създаде криптиран файл в  {file}",
    "{file} was created in a public folder" : "{file} беше създаден в публична папка",
    "You changed {file}" : "Променихте {file}",
    "You changed an encrypted file in {file}" : "Променихте криптиран файл в {file}",
    "{user} changed {file}" : "{user} промени {file}",
    "{user} changed an encrypted file in {file}" : "{user} промени криптиран файл в  {file}",
    "You deleted {file}" : "Изтрихте {file}",
    "You deleted an encrypted file in {file}" : "Изтрихте криптиран файл в {file}",
    "{user} deleted {file}" : "{user} изтри {file}",
    "{user} deleted an encrypted file in {file}" : "{user} изтри криптиран файл в  {file}",
    "You restored {file}" : "Възстановихте {file}",
    "{user} restored {file}" : "{user} възстанови {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Преименувахте {oldfile} (скрит) на {newfile} (скрит)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Преименувахте {oldfile} (скрит) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Преименувахте {oldfile} на {newfile} (скрит)",
    "You renamed {oldfile} to {newfile}" : "Преименувахте {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} преименува {oldfile} (скрит) на {newfile} (скрит)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} преименува {oldfile} (скрит) на {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} преименува {oldfile} на {newfile} (скрит)",
    "{user} renamed {oldfile} to {newfile}" : "{user} преименува {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Преместихте {oldfile} в {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} премести {oldfile} в {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Добавяне или премахване на файл от <strong>любимите</strong> ви",
    "Files" : "Файлове",
    "A file or folder has been <strong>changed</strong>" : "<strong>Промяна</strong> на файл / папка",
    "A favorite file or folder has been <strong>changed</strong>" : "Предпочетен файл или папка е <strong>променен</strong>",
    "No favorites" : "Няма любими",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "Accept" : "Приемане",
    "Reject" : "Откажи",
    "Incoming ownership transfer from {user}" : "Входящо прехвърляне на собственост от {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : " Ще приеметели {path}?\n\nЗабележка: Процесът на прехвърляне след приемане може да отнеме до 1 час.",
    "Ownership transfer failed" : "Промяната на собственик е неуспешна",
    "Your ownership transfer of {path} to {user} failed." : "Вашето прехвърляне на собственост на {path} към {user} беше  неуспешно.",
    "The ownership transfer of {path} from {user} failed." : "Прехвърлянето на собственост на {path} към {user} беше  неуспешно.",
    "Ownership transfer done" : "Промяната на собственик е успешна",
    "Your ownership transfer of {path} to {user} has completed." : "Вашето прехвърляне на собственост на {path} към {user} е завършено.",
    "The ownership transfer of {path} from {user} has completed." : "Прехвърлянето на собственост на {path} към {user} е завършено.",
    "in %s" : "в %s",
    "File Management" : "Управление на файлове",
    "Home" : "Домашен",
    "Target folder does not exist any more" : "Дестинацията не съществува",
    "Reload current directory" : "Презареждане на текущата директория",
    "Go to the \"{dir}\" directory" : "Отидете в директорията \"{dir}\"",
    "Favorite" : "Любими",
    "Filename" : "Име на файла",
    "Folder name" : "Име на папка",
    "Folder" : "Папка",
    "Pending" : "Чакащо",
    "Clear filter" : "Изчстиване на филтър",
    "Modified" : "Промяна",
    "Type" : "Тип",
    "Active filters" : "Актижни филтри",
    "Total rows summary" : "Обобщение на общия брой редове",
    "Name" : "Име",
    "Size" : "Размер",
    "\"{displayName}\" batch action executed successfully" : " Пакетното действие „{displayName}“ е изпълнено успешно",
    "\"{displayName}\" action failed" : "Действието „{displayName}“ е неуспешно",
    "Actions" : "Действия",
    "File not found" : "Файлът не е намерен",
    "{usedQuotaByte} used" : "{usedQuotaByte} използвано",
    "{used} of {quota} used" : "{used} от {quota} използвани",
    "{relative}% used" : "{relative}% използвано",
    "Could not refresh storage stats" : "Статистиката за хранилище не можа да се обнови",
    "Your storage is full, files can not be updated or synced anymore!" : "Хранилището е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "New folder" : "Нова папка",
    "Create new folder" : "Създай нова папка",
    "Create" : "Създаване",
    "Submit" : "Изпращане",
    "Choose a file or folder to transfer" : "Избор на файл или папка за прехвърляне",
    "Transfer" : "Прехвърли",
    "Transfer {path} to {userid}" : "Прехвърляне на  {path} към {userid}",
    "Invalid path selected" : "Предоставен е невалиден път до файл.",
    "Unknown error" : "Неизвестна грешка",
    "Ownership transfer request sent" : "Изпратена заявка за прехвърляне на собствеността",
    "Cannot transfer ownership of a file or folder you do not own" : "Не можете да прехвърляте собственост върху файл или папка, които не притежавате",
    "Transfer ownership of a file or folder" : "Прехвърляне на собственост на файл или папка",
    "Choose file or folder to transfer" : "Избор на файл или папка за прехвърляне",
    "Change" : "Промени",
    "New owner" : "Нов собственик",
    "Select file or folder to link to" : "Избор на файл или папка, към които да поставите връзка",
    "Share" : "Споделяне",
    "Shared by link" : "Споделени с връзка",
    "Shared" : "Споделен",
    "Switch to list view" : "Превключване към изглед на списък",
    "Not enough free space" : "Няма достатъчно свободно място",
    "Operation is blocked by access control" : "Операцията се блокира от контрол на достъпа",
    "\"{displayName}\" action executed successfully" : "Действието „{displayName}“ е изпълнено успешно",
    "Loading current folder" : "Зареждане на текущата папка",
    "Retry" : "Опитай отново",
    "No files in here" : "Няма файлове",
    "Upload some content or sync with your devices!" : "Качете съдържание или синхронизирайте с вашите устройства!",
    "Go back" : "Назад",
    "Views" : "Изгледи",
    "Files settings" : "Настройки на файловете",
    "File cannot be accessed" : "Файлът не е достъпен",
    "Clipboard is not available" : "Клипбордът не е достъпен",
    "WebDAV URL copied to clipboard" : "WebDAV URL адрес е копиран в клипборда",
    "Show hidden files" : "Показвай и скрити файлове",
    "Crop image previews" : "Изрязване на визуализациите на изображение",
    "Additional settings" : "Допълнителни настройки",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Копиране в клипборда",
    "Use this address to access your Files via WebDAV" : "Ползвайте този адрес за достъп до файловете си чрез WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако сте активирали 2FA, трябва да създадете и използвате нова парола за приложението, като кликнете тук.",
    "Keyboard shortcuts" : "Бързи клавиши",
    "Selection" : "Избор",
    "Navigation" : "Навигация",
    "View" : "Изглед",
    "Error while loading the file data" : "Грешка при зареждането на файловете.",
    "Owner" : "Създател",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "Tags" : "Етикети",
    "Blank" : "Празен",
    "Unable to create new file from template" : "Не може да се създаде нов файл от шаблон",
    "Pick a template for {name}" : "Избор на шаблон за {name}",
    "Create a new file with the selected template" : "Създаване на нов файл с избрания шаблон",
    "Creating file" : "Създаване на файл ",
    "Disconnect storage" : "Извади хранилището",
    "Delete permanently" : "Изтрий завинаги",
    "Delete file" : "Изтриване на файлове",
    "Delete files" : "Изтриване на файлове",
    "Delete folder" : "Изтриване на папка",
    "Delete" : "Изтрий",
    "Cancel" : "Отказ",
    "Copy" : "Копирай",
    "Move" : "Преместване",
    "Move or copy" : "Премести или копирай",
    "Open file locally" : "Локално отваряне на файл",
    "Failed to redirect to client" : "Неуспешно пренасочване към клиент",
    "Open locally" : "Локално отваряне",
    "Rename" : "Преименувай",
    "Open details" : "Отваряне на подробности",
    "View in folder" : "Преглед в папката",
    "Today" : "Днес",
    "Documents" : "Документи",
    "Folders" : "Папки",
    "Audio" : "Аудио",
    "Videos" : "Видеа",
    "Unable to initialize the templates directory" : "Неуспешно инициализиране на директорията с шаблони",
    "Templates" : "Шаблони",
    "Some files could not be moved" : "Някои файлове не могат да бъдат преместени",
    "This operation is forbidden" : "Операцията е забранена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорията не е налична. Проверете журнала или се свържете с администратора",
    "Storage is temporarily not available" : "Временно хранилището не е налично",
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "No favorites yet" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които маркирате като любими ще се показват тук",
    "All files" : "Всички файлове",
    "Recent" : "Последни",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитвате да качите са по-големи от позволеното на сървъра.",
    "File could not be found" : "Файлът не може да бъде намерен",
    "Download" : "Изтегли",
    "Show list view" : "Показване с изглед на списък",
    "Show grid view" : "Показване в решетъчен изглед",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Папката \"{dir}\" не може да бъде създадена",
    "This will stop your current uploads." : "Това ще прекрати всички ваши текущи процеси по качване на файлове.",
    "Upload cancelled." : "Качването е прекъснато.",
    "Processing files …" : "Обработване на файлове ...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или с размер 0 байта.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място. Опитвате да качите {size1} при свободни само {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Дестинацията \"{dir}\" не съществува",
    "An unknown error has occurred" : "Възникна неизвестна грешка",
    "File could not be uploaded" : " Файлът не може да бъде качен",
    "Uploading …" : "Качване …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} от {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Качването на такъв файл не се поддържа",
    "Error when assembling chunks, status code {status}" : "Грешка при асемлиране на парчетата, код {status}",
    "Choose target folder" : "Избор на папка",
    "Edit locally" : "Локално редактиране",
    "Open" : "Отвори",
    "Could not load info for file \"{file}\"" : "Информацията за файла \"{file}\" не може да бъде заредена",
    "Details" : "Подробности",
    "Please select tag(s) to add to the selection" : "Моля, изберете етикет(и), който да добавите към селекцията",
    "Apply tag(s) to selection" : "Прилагане на етикет(и) към селекцията",
    "Select directory \"{dirName}\"" : "Избор на директория „{dirName}“",
    "Select file \"{fileName}\"" : "Избор на файл \"{fileName}\"",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "Could not move \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде преместен, дестинацията съществува",
    "Could not move \"{file}\"" : "Файлът \"{file}\" не може да бъде преместен",
    "copy" : "Копиране",
    "Could not copy \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде копиран, дестинацията съществува",
    "Could not copy \"{file}\"" : "Файлът \"{file}\" не може да бъде копиран",
    "Copied {origin} inside {destination}" : "Копирано {origin} в {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирано {origin} и {nbfiles} други файлове в {destination}",
    "{newName} already exists" : "{newName} вече съществува",
    "Could not rename \"{fileName}\", it does not exist any more" : "Файлът \"{fileName}\" не може да бъде преименуван защото не съществува",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" се ползва в директорията \"{dir}\". Моля, изберете друго име.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" не може да бъде преименуван",
    "Could not create file \"{file}\"" : "Файлът \"{file}\" не може да бъде създаден",
    "Could not create file \"{file}\" because it already exists" : "Файлът \"{file}\" не може да бъде създаден защото вече съществува",
    "Could not create folder \"{dir}\" because it already exists" : "Папката \"{dir}\" не може да бъде създадена защото вече съществува",
    "Could not fetch file details \"{file}\"" : "Подробностите за файла „{file}“ не можаха да бъдат извлечени",
    "Error deleting file \"{fileName}\"." : "Грешка при изтриването на файла \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Няма резултати от търсенето в други папки за {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Въведете повече от два знака за търсене в други папки",
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включително %n скрит","включително %n скрити"],
    "You do not have permission to upload or create files here" : "Нямате право да качвате или създавате файлове тук",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла"],
    "New" : "Нов",
    "New file/folder menu" : "Ново меню за файл/папка",
    "Select file range" : "Избери от файловете",
    "{used}%" : "{used}%",
    "{used} used" : "{used} използвани",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "\"/\" is not allowed inside a file name." : "\"/\" е непозволен знак в името на файла.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е разрешен тип файл",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Хранилището на {owner} е запълнено и файловете вече не могат да се актуализират или синхронизират!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Груповата папка \"{mountPoint}“ е пълна, файловете вече не могат да се актуализират или синхронизират!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Външното хранилище е \"{mountPoint}“ е пълно, файловете вече не могат да се актуализират или синхронизират!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Вашето хранилище запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Хранилището на {owner} е почти запълнено ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Груповата папка \"{mountPoint}“  е почти пълна ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Външното хранилище е \"{mountPoint}“  е почти пълно ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Вашето хранилище е почти запълнено ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["съвпада с \"{filter}\"","съвпада с \"{filter}\""],
    "Path" : "Път",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
    "Favorited" : "Отбелязано в любими",
    "Upload file" : "Качи файл",
    "Not favorited" : "Премахни от любими",
    "An error occurred while trying to update the tags" : "Възникна грешка при опита за промяна на етикети",
    "Storage informations" : "Хранилище на  информация",
    "Go to the previous folder" : "Връщане към предишната папка",
    "Open the files app settings" : "Отваряне на настройките на приложението за файлове",
    "Unable to change the favourite state of the file" : "Не може да се промени състоянието за предпочитане на файла",
    "Create new templates folder" : "Създаване на нова папка за шаблони",
    "Text file" : "Текстов файл",
    "New text file.txt" : "Текстов файл.txt"
},
"nplurals=2; plural=(n != 1);");
